import sys
import unittest
import platformdirs
import appdirs

if sys.version_info[0] < 3:
    STRING_TYPE = basestring
else:
    STRING_TYPE = str


class Test_PlatformDirs(unittest.TestCase):
    def test_metadata(self):
        self.assertTrue(hasattr(platformdirs, "__version__"))
        self.assertTrue(hasattr(platformdirs, "__version_info__"))

    def test_helpers(self):
        self.assertIsInstance(
            platformdirs.user_data_dir('MyApp', 'MyCompany'), STRING_TYPE)
        self.assertIsInstance(
            platformdirs.site_data_dir('MyApp', 'MyCompany'), STRING_TYPE)
        self.assertIsInstance(
            platformdirs.user_cache_dir('MyApp', 'MyCompany'), STRING_TYPE)
        self.assertIsInstance(
            platformdirs.user_state_dir('MyApp', 'MyCompany'), STRING_TYPE)
        self.assertIsInstance(
            platformdirs.user_log_dir('MyApp', 'MyCompany'), STRING_TYPE)

    def test_dirs(self):
        dirs = platformdirs.PlatformDirs('MyApp', 'MyCompany', version='1.0')
        self.assertIsInstance(dirs.user_data_dir, STRING_TYPE)
        self.assertIsInstance(dirs.site_data_dir, STRING_TYPE)
        self.assertIsInstance(dirs.user_cache_dir, STRING_TYPE)
        self.assertIsInstance(dirs.user_state_dir, STRING_TYPE)
        self.assertIsInstance(dirs.user_log_dir, STRING_TYPE)

    def test_backward_compatibility_basic(self):
        self.assertEqual(platformdirs.user_data_dir(), appdirs.user_data_dir())
        self.assertEqual(platformdirs.site_data_dir(), appdirs.site_data_dir())
        self.assertEqual(platformdirs.user_config_dir(), appdirs.user_config_dir())
        self.assertEqual(platformdirs.site_config_dir(), appdirs.site_config_dir())
        self.assertEqual(platformdirs.user_cache_dir(), appdirs.user_cache_dir())
        self.assertEqual(platformdirs.user_state_dir(), appdirs.user_state_dir())

        # Calling `appdirs.user_log_dir` without appname produces NoneType error on macOS
        if sys.platform == 'darwin':
            self.assertTrue(isinstance(platformdirs.user_log_dir(), str))
        else:
            self.assertEqual(platformdirs.user_log_dir(), appdirs.user_log_dir())

    def test_backward_compatibility_appname(self):
        kwargs = {'appname': 'foo'}
        self.assertEqual(platformdirs.user_data_dir(**kwargs), appdirs.user_data_dir(**kwargs))
        self.assertEqual(platformdirs.site_data_dir(**kwargs), appdirs.site_data_dir(**kwargs))
        self.assertEqual(platformdirs.user_config_dir(**kwargs), appdirs.user_config_dir(**kwargs))
        self.assertEqual(platformdirs.site_config_dir(**kwargs), appdirs.site_config_dir(**kwargs))
        self.assertEqual(platformdirs.user_cache_dir(**kwargs), appdirs.user_cache_dir(**kwargs))
        self.assertEqual(platformdirs.user_state_dir(**kwargs), appdirs.user_state_dir(**kwargs))
        self.assertEqual(platformdirs.user_log_dir(**kwargs), appdirs.user_log_dir(**kwargs))

    def test_backward_compatibility_appname_appauthor(self):
        kwargs = {'appname': 'foo', 'appauthor': 'bar'}
        self.assertEqual(platformdirs.user_data_dir(**kwargs), appdirs.user_data_dir(**kwargs))
        self.assertEqual(platformdirs.site_data_dir(**kwargs), appdirs.site_data_dir(**kwargs))
        self.assertEqual(platformdirs.user_config_dir(**kwargs), appdirs.user_config_dir(**kwargs))
        self.assertEqual(platformdirs.site_config_dir(**kwargs), appdirs.site_config_dir(**kwargs))
        self.assertEqual(platformdirs.user_cache_dir(**kwargs), appdirs.user_cache_dir(**kwargs))
        self.assertEqual(platformdirs.user_state_dir(**kwargs), appdirs.user_state_dir(**kwargs))
        self.assertEqual(platformdirs.user_log_dir(**kwargs), appdirs.user_log_dir(**kwargs))

    def test_backward_compatibility_appname_appauthor_version(self):
        kwargs = {'appname': 'foo', 'appauthor': 'bar', 'version': 'v1.0'}
        self.assertEqual(platformdirs.user_data_dir(**kwargs), appdirs.user_data_dir(**kwargs))
        self.assertEqual(platformdirs.site_data_dir(**kwargs), appdirs.site_data_dir(**kwargs))
        self.assertEqual(platformdirs.user_config_dir(**kwargs), appdirs.user_config_dir(**kwargs))
        self.assertEqual(platformdirs.site_config_dir(**kwargs), appdirs.site_config_dir(**kwargs))
        self.assertEqual(platformdirs.user_cache_dir(**kwargs), appdirs.user_cache_dir(**kwargs))
        self.assertEqual(platformdirs.user_state_dir(**kwargs), appdirs.user_state_dir(**kwargs))
        self.assertEqual(platformdirs.user_log_dir(**kwargs), appdirs.user_log_dir(**kwargs))

if __name__ == "__main__":
    unittest.main()



#!/usr/bin/env python
from io import open
import os
import ast
from setuptools import setup


def read(fname):
    inf = open(os.path.join(os.path.dirname(__file__), fname), encoding='utf8')
    out = "\n" + inf.read().replace("\r\n", "\n")
    inf.close()
    return out


# Do not import `platformdirs` yet, lest we import some random version on sys.path.
for line in read("platformdirs.py").splitlines():
    if line.startswith("__version__"):
        version = ast.literal_eval(line.split("=", 1)[1].strip())
        break


setup(
    name='platformdirs',
    version=version,
    description='A small Python module for determining appropriate ' + \
        'platform-specific dirs, e.g. a "user data dir".',
    long_description=read('README.rst') + '\n' + read('CHANGES.rst'),
    python_requires='>=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Programming Language :: Python :: Implementation :: CPython',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    keywords='application directory log cache user',
    author='Trent Mick',
    author_email='trentm@gmail.com',
    maintainer='Jeff Rouse',
    maintainer_email='jr@its.to',
    url='https://github.com/platformdirs/platformdirs',
    license='MIT',
    py_modules=["platformdirs"],
)
